# -*- coding: utf-8 -*-
"""Installer for the imio.smartweb.policy package."""

from setuptools import find_packages
from setuptools import setup


long_description = "\n\n".join(
    [
        open("README.rst").read(),
        open("CONTRIBUTORS.rst").read(),
        open("CHANGES.rst").read(),
    ]
)


setup(
    name="imio.smartweb.policy",
    version="1.0.9",
    description="Policies to setup imio.smartweb",
    long_description=long_description,
    # Get more from https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: Addon",
        "Framework :: Plone :: 6.0",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
    ],
    keywords="Python Plone CMS",
    author="Christophe Boulanger",
    author_email="christophe.boulanger@imio.be",
    url="https://github.com/imio/imio.smartweb.policy",
    project_urls={
        "PyPI": "https://pypi.python.org/pypi/imio.smartweb.policy",
        "Source": "https://github.com/imio/imio.smartweb.policy",
        "Tracker": "https://github.com/imio/imio.smartweb.policy/issues",
        # 'Documentation': 'https://imio.smartweb.policy.readthedocs.io/en/latest/',
    },
    license="GPL version 2",
    packages=find_packages("src", exclude=["ez_setup"]),
    namespace_packages=["imio", "imio.smartweb"],
    package_dir={"": "src"},
    include_package_data=True,
    zip_safe=False,
    python_requires=">=3.8",
    install_requires=[
        "setuptools",
        # -*- Extra requirements: -*-
        "z3c.jbot",
        "plone.api>=1.8.4",
        "plone.app.dexterity",
        "plone.app.imagecropping",
        "collective.autopublishing",
        "collective.autoscaling",
        "collective.big.bang",
        "collective.messagesviewlet",
        "collective.pivot",
        "collective.solr",
        "collective.themefragments",
        "collective.z3cform.select2",
        "eea.facetednavigation",
        "pas.plugins.imio",
        "imio.gdpr",
        "imio.smartweb.core",
        "imio.smartweb.locales",
        "imio.prometheus",
    ],
    extras_require={
        "test": [
            "plone.app.testing",
            # Plone KGS does not use this version, because it would break
            # Remove if your package shall be part of coredev.
            # plone_coredev tests as of 2016-04-01.
            "plone.testing>=5.0.0",
            "plone.app.contenttypes",
            "plone.app.robotframework[debug]",
        ],
    },
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)
